# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/authz.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&injective/exchange/v1beta1/authz.proto\x12\x1ainjective.exchange.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\"Y\n\x19\x43reateSpotLimitOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"Z\n\x1a\x43reateSpotMarketOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"_\n\x1f\x42\x61tchCreateSpotLimitOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"T\n\x14\x43\x61ncelSpotOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"Z\n\x1a\x42\x61tchCancelSpotOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"_\n\x1f\x43reateDerivativeLimitOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"`\n CreateDerivativeMarketOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"e\n%BatchCreateDerivativeLimitOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"Z\n\x1a\x43\x61ncelDerivativeOrderAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"`\n BatchCancelDerivativeOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t:\x11\xd2\xb4-\rAuthorization\"t\n\x16\x42\x61tchUpdateOrdersAuthz\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x14\n\x0cspot_markets\x18\x02 \x03(\t\x12\x1a\n\x12\x64\x65rivative_markets\x18\x03 \x03(\t:\x11\xd2\xb4-\rAuthorizationBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,])




_CREATESPOTLIMITORDERAUTHZ = _descriptor.Descriptor(
  name='CreateSpotLimitOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateSpotLimitOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateSpotLimitOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateSpotLimitOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=186,
)


_CREATESPOTMARKETORDERAUTHZ = _descriptor.Descriptor(
  name='CreateSpotMarketOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateSpotMarketOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateSpotMarketOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateSpotMarketOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=278,
)


_BATCHCREATESPOTLIMITORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCreateSpotLimitOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=375,
)


_CANCELSPOTORDERAUTHZ = _descriptor.Descriptor(
  name='CancelSpotOrderAuthz',
  full_name='injective.exchange.v1beta1.CancelSpotOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CancelSpotOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CancelSpotOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=461,
)


_BATCHCANCELSPOTORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCancelSpotOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=553,
)


_CREATEDERIVATIVELIMITORDERAUTHZ = _descriptor.Descriptor(
  name='CreateDerivativeLimitOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=650,
)


_CREATEDERIVATIVEMARKETORDERAUTHZ = _descriptor.Descriptor(
  name='CreateDerivativeMarketOrderAuthz',
  full_name='injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=748,
)


_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCreateDerivativeLimitOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=851,
)


_CANCELDERIVATIVEORDERAUTHZ = _descriptor.Descriptor(
  name='CancelDerivativeOrderAuthz',
  full_name='injective.exchange.v1beta1.CancelDerivativeOrderAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.CancelDerivativeOrderAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.CancelDerivativeOrderAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=943,
)


_BATCHCANCELDERIVATIVEORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchCancelDerivativeOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_ids', full_name='injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz.market_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1041,
)


_BATCHUPDATEORDERSAUTHZ = _descriptor.Descriptor(
  name='BatchUpdateOrdersAuthz',
  full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_markets', full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz.spot_markets', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_markets', full_name='injective.exchange.v1beta1.BatchUpdateOrdersAuthz.derivative_markets', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1159,
)

DESCRIPTOR.message_types_by_name['CreateSpotLimitOrderAuthz'] = _CREATESPOTLIMITORDERAUTHZ
DESCRIPTOR.message_types_by_name['CreateSpotMarketOrderAuthz'] = _CREATESPOTMARKETORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCreateSpotLimitOrdersAuthz'] = _BATCHCREATESPOTLIMITORDERSAUTHZ
DESCRIPTOR.message_types_by_name['CancelSpotOrderAuthz'] = _CANCELSPOTORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCancelSpotOrdersAuthz'] = _BATCHCANCELSPOTORDERSAUTHZ
DESCRIPTOR.message_types_by_name['CreateDerivativeLimitOrderAuthz'] = _CREATEDERIVATIVELIMITORDERAUTHZ
DESCRIPTOR.message_types_by_name['CreateDerivativeMarketOrderAuthz'] = _CREATEDERIVATIVEMARKETORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCreateDerivativeLimitOrdersAuthz'] = _BATCHCREATEDERIVATIVELIMITORDERSAUTHZ
DESCRIPTOR.message_types_by_name['CancelDerivativeOrderAuthz'] = _CANCELDERIVATIVEORDERAUTHZ
DESCRIPTOR.message_types_by_name['BatchCancelDerivativeOrdersAuthz'] = _BATCHCANCELDERIVATIVEORDERSAUTHZ
DESCRIPTOR.message_types_by_name['BatchUpdateOrdersAuthz'] = _BATCHUPDATEORDERSAUTHZ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSpotLimitOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateSpotLimitOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPOTLIMITORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateSpotLimitOrderAuthz)
  })
_sym_db.RegisterMessage(CreateSpotLimitOrderAuthz)

CreateSpotMarketOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateSpotMarketOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPOTMARKETORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateSpotMarketOrderAuthz)
  })
_sym_db.RegisterMessage(CreateSpotMarketOrderAuthz)

BatchCreateSpotLimitOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCreateSpotLimitOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCREATESPOTLIMITORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCreateSpotLimitOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCreateSpotLimitOrdersAuthz)

CancelSpotOrderAuthz = _reflection.GeneratedProtocolMessageType('CancelSpotOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CANCELSPOTORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CancelSpotOrderAuthz)
  })
_sym_db.RegisterMessage(CancelSpotOrderAuthz)

BatchCancelSpotOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCancelSpotOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCANCELSPOTORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCancelSpotOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCancelSpotOrdersAuthz)

CreateDerivativeLimitOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateDerivativeLimitOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDERIVATIVELIMITORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateDerivativeLimitOrderAuthz)
  })
_sym_db.RegisterMessage(CreateDerivativeLimitOrderAuthz)

CreateDerivativeMarketOrderAuthz = _reflection.GeneratedProtocolMessageType('CreateDerivativeMarketOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDERIVATIVEMARKETORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CreateDerivativeMarketOrderAuthz)
  })
_sym_db.RegisterMessage(CreateDerivativeMarketOrderAuthz)

BatchCreateDerivativeLimitOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCreateDerivativeLimitOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCREATEDERIVATIVELIMITORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCreateDerivativeLimitOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCreateDerivativeLimitOrdersAuthz)

CancelDerivativeOrderAuthz = _reflection.GeneratedProtocolMessageType('CancelDerivativeOrderAuthz', (_message.Message,), {
  'DESCRIPTOR' : _CANCELDERIVATIVEORDERAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CancelDerivativeOrderAuthz)
  })
_sym_db.RegisterMessage(CancelDerivativeOrderAuthz)

BatchCancelDerivativeOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchCancelDerivativeOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCANCELDERIVATIVEORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchCancelDerivativeOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchCancelDerivativeOrdersAuthz)

BatchUpdateOrdersAuthz = _reflection.GeneratedProtocolMessageType('BatchUpdateOrdersAuthz', (_message.Message,), {
  'DESCRIPTOR' : _BATCHUPDATEORDERSAUTHZ,
  '__module__' : 'injective.exchange.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BatchUpdateOrdersAuthz)
  })
_sym_db.RegisterMessage(BatchUpdateOrdersAuthz)


DESCRIPTOR._options = None
_CREATESPOTLIMITORDERAUTHZ._options = None
_CREATESPOTMARKETORDERAUTHZ._options = None
_BATCHCREATESPOTLIMITORDERSAUTHZ._options = None
_CANCELSPOTORDERAUTHZ._options = None
_BATCHCANCELSPOTORDERSAUTHZ._options = None
_CREATEDERIVATIVELIMITORDERAUTHZ._options = None
_CREATEDERIVATIVEMARKETORDERAUTHZ._options = None
_BATCHCREATEDERIVATIVELIMITORDERSAUTHZ._options = None
_CANCELDERIVATIVEORDERAUTHZ._options = None
_BATCHCANCELDERIVATIVEORDERSAUTHZ._options = None
_BATCHUPDATEORDERSAUTHZ._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_oracle_rpc_pb2 as exchange_dot_injective__oracle__rpc__pb2


class InjectiveOracleRPCStub(object):
    """InjectiveOracleRPC defines gRPC API of Exchange Oracle provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.OracleList = channel.unary_unary(
                '/injective_oracle_rpc.InjectiveOracleRPC/OracleList',
                request_serializer=exchange_dot_injective__oracle__rpc__pb2.OracleListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__oracle__rpc__pb2.OracleListResponse.FromString,
                )
        self.Price = channel.unary_unary(
                '/injective_oracle_rpc.InjectiveOracleRPC/Price',
                request_serializer=exchange_dot_injective__oracle__rpc__pb2.PriceRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__oracle__rpc__pb2.PriceResponse.FromString,
                )
        self.StreamPrices = channel.unary_stream(
                '/injective_oracle_rpc.InjectiveOracleRPC/StreamPrices',
                request_serializer=exchange_dot_injective__oracle__rpc__pb2.StreamPricesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__oracle__rpc__pb2.StreamPricesResponse.FromString,
                )


class InjectiveOracleRPCServicer(object):
    """InjectiveOracleRPC defines gRPC API of Exchange Oracle provider.
    """

    def OracleList(self, request, context):
        """List all oracles
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Price(self, request, context):
        """Gets the price of the oracle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamPrices(self, request, context):
        """StreamPrices streams new price changes for a specified oracle. If no oracles
        are provided, all price changes are streamed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveOracleRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'OracleList': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleList,
                    request_deserializer=exchange_dot_injective__oracle__rpc__pb2.OracleListRequest.FromString,
                    response_serializer=exchange_dot_injective__oracle__rpc__pb2.OracleListResponse.SerializeToString,
            ),
            'Price': grpc.unary_unary_rpc_method_handler(
                    servicer.Price,
                    request_deserializer=exchange_dot_injective__oracle__rpc__pb2.PriceRequest.FromString,
                    response_serializer=exchange_dot_injective__oracle__rpc__pb2.PriceResponse.SerializeToString,
            ),
            'StreamPrices': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamPrices,
                    request_deserializer=exchange_dot_injective__oracle__rpc__pb2.StreamPricesRequest.FromString,
                    response_serializer=exchange_dot_injective__oracle__rpc__pb2.StreamPricesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_oracle_rpc.InjectiveOracleRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveOracleRPC(object):
    """InjectiveOracleRPC defines gRPC API of Exchange Oracle provider.
    """

    @staticmethod
    def OracleList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_oracle_rpc.InjectiveOracleRPC/OracleList',
            exchange_dot_injective__oracle__rpc__pb2.OracleListRequest.SerializeToString,
            exchange_dot_injective__oracle__rpc__pb2.OracleListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Price(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_oracle_rpc.InjectiveOracleRPC/Price',
            exchange_dot_injective__oracle__rpc__pb2.PriceRequest.SerializeToString,
            exchange_dot_injective__oracle__rpc__pb2.PriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_oracle_rpc.InjectiveOracleRPC/StreamPrices',
            exchange_dot_injective__oracle__rpc__pb2.StreamPricesRequest.SerializeToString,
            exchange_dot_injective__oracle__rpc__pb2.StreamPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/blockchain/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/blockchain/types.proto',
  package='tendermint.blockchain',
  syntax='proto3',
  serialized_options=b'Z<github.com/tendermint/tendermint/proto/tendermint/blockchain',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!tendermint/blockchain/types.proto\x12\x15tendermint.blockchain\x1a\x1ctendermint/types/block.proto\"\x1e\n\x0c\x42lockRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"!\n\x0fNoBlockResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\"7\n\rBlockResponse\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.tendermint.types.Block\"\x0f\n\rStatusRequest\".\n\x0eStatusResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x03\"\xd5\x02\n\x07Message\x12<\n\rblock_request\x18\x01 \x01(\x0b\x32#.tendermint.blockchain.BlockRequestH\x00\x12\x43\n\x11no_block_response\x18\x02 \x01(\x0b\x32&.tendermint.blockchain.NoBlockResponseH\x00\x12>\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32$.tendermint.blockchain.BlockResponseH\x00\x12>\n\x0estatus_request\x18\x04 \x01(\x0b\x32$.tendermint.blockchain.StatusRequestH\x00\x12@\n\x0fstatus_response\x18\x05 \x01(\x0b\x32%.tendermint.blockchain.StatusResponseH\x00\x42\x05\n\x03sumB>Z<github.com/tendermint/tendermint/proto/tendermint/blockchainb\x06proto3'
  ,
  dependencies=[tendermint_dot_types_dot_block__pb2.DESCRIPTOR,])




_BLOCKREQUEST = _descriptor.Descriptor(
  name='BlockRequest',
  full_name='tendermint.blockchain.BlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.blockchain.BlockRequest.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=120,
)


_NOBLOCKRESPONSE = _descriptor.Descriptor(
  name='NoBlockResponse',
  full_name='tendermint.blockchain.NoBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.blockchain.NoBlockResponse.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=155,
)


_BLOCKRESPONSE = _descriptor.Descriptor(
  name='BlockResponse',
  full_name='tendermint.blockchain.BlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='tendermint.blockchain.BlockResponse.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=212,
)


_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='tendermint.blockchain.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=229,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='tendermint.blockchain.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.blockchain.StatusResponse.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='tendermint.blockchain.StatusResponse.base', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=277,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.blockchain.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_request', full_name='tendermint.blockchain.Message.block_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_block_response', full_name='tendermint.blockchain.Message.no_block_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_response', full_name='tendermint.blockchain.Message.block_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_request', full_name='tendermint.blockchain.Message.status_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_response', full_name='tendermint.blockchain.Message.status_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.blockchain.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=621,
)

_BLOCKRESPONSE.fields_by_name['block'].message_type = tendermint_dot_types_dot_block__pb2._BLOCK
_MESSAGE.fields_by_name['block_request'].message_type = _BLOCKREQUEST
_MESSAGE.fields_by_name['no_block_response'].message_type = _NOBLOCKRESPONSE
_MESSAGE.fields_by_name['block_response'].message_type = _BLOCKRESPONSE
_MESSAGE.fields_by_name['status_request'].message_type = _STATUSREQUEST
_MESSAGE.fields_by_name['status_response'].message_type = _STATUSRESPONSE
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['block_request'])
_MESSAGE.fields_by_name['block_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['no_block_response'])
_MESSAGE.fields_by_name['no_block_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['block_response'])
_MESSAGE.fields_by_name['block_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['status_request'])
_MESSAGE.fields_by_name['status_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['status_response'])
_MESSAGE.fields_by_name['status_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['BlockRequest'] = _BLOCKREQUEST
DESCRIPTOR.message_types_by_name['NoBlockResponse'] = _NOBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['BlockResponse'] = _BLOCKRESPONSE
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockRequest = _reflection.GeneratedProtocolMessageType('BlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKREQUEST,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.BlockRequest)
  })
_sym_db.RegisterMessage(BlockRequest)

NoBlockResponse = _reflection.GeneratedProtocolMessageType('NoBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOBLOCKRESPONSE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.NoBlockResponse)
  })
_sym_db.RegisterMessage(NoBlockResponse)

BlockResponse = _reflection.GeneratedProtocolMessageType('BlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKRESPONSE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.BlockResponse)
  })
_sym_db.RegisterMessage(BlockResponse)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATUSREQUEST,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.StatusRequest)
  })
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRESPONSE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.StatusResponse)
  })
_sym_db.RegisterMessage(StatusResponse)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.blockchain.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.blockchain.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from injective.oracle.v1beta1 import genesis_pb2 as injective_dot_oracle_dot_v1beta1_dot_genesis__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/query.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$injective/oracle/v1beta1/query.proto\x12\x18injective.oracle.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a&injective/oracle/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\x1a\n\x18QueryBandRelayersRequest\"-\n\x19QueryBandRelayersResponse\x12\x10\n\x08relayers\x18\x01 \x03(\t\"\x1d\n\x1bQueryBandPriceStatesRequest\"^\n\x1cQueryBandPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\" \n\x1eQueryBandIBCPriceStatesRequest\"a\n\x1fQueryBandIBCPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceState\"\"\n QueryPriceFeedPriceStatesRequest\"c\n!QueryPriceFeedPriceStatesResponse\x12>\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedState\"!\n\x1fQueryCoinbasePriceStatesRequest\"f\n QueryCoinbasePriceStatesResponse\x12\x42\n\x0cprice_states\x18\x01 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceState\"B\n\x1eQueryProviderPriceStateRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\"\\\n\x1fQueryProviderPriceStateResponse\x12\x39\n\x0bprice_state\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\"\x19\n\x17QueryModuleStateRequest\"Q\n\x18QueryModuleStateResponse\x12\x35\n\x05state\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.GenesisState\"m\n\"QueryHistoricalPriceRecordsRequest\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\"d\n#QueryHistoricalPriceRecordsResponse\x12=\n\rprice_records\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecords\"^\n\x14OracleHistoryOptions\x12\x0f\n\x07max_age\x18\x01 \x01(\x04\x12\x1b\n\x13include_raw_history\x18\x02 \x01(\x08\x12\x18\n\x10include_metadata\x18\x03 \x01(\x08\"\xe1\x01\n\x1cQueryOracleVolatilityRequest\x12\x37\n\tbase_info\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfo\x12\x38\n\nquote_info\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfo\x12N\n\x16oracle_history_options\x18\x03 \x01(\x0b\x32..injective.oracle.v1beta1.OracleHistoryOptions\"\xe3\x01\n\x1dQueryOracleVolatilityResponse\x12>\n\nvolatility\x18\x01 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatistics\x12:\n\x0braw_history\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecord\"!\n\x1fQueryOracleProvidersInfoRequest\"]\n QueryOracleProvidersInfoResponse\x12\x39\n\tproviders\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.ProviderInfo\"4\n QueryOracleProviderPricesRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\"c\n!QueryOracleProviderPricesResponse\x12>\n\rproviderState\x18\x01 \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderState2\xe3\x11\n\x05Query\x12\x8f\x01\n\x06Params\x12,.injective.oracle.v1beta1.QueryParamsRequest\x1a-.injective.oracle.v1beta1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/oracle/v1beta1/params\x12\xa8\x01\n\x0c\x42\x61ndRelayers\x12\x32.injective.oracle.v1beta1.QueryBandRelayersRequest\x1a\x33.injective.oracle.v1beta1.QueryBandRelayersResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/oracle/v1beta1/band_relayers\x12\xb5\x01\n\x0f\x42\x61ndPriceStates\x12\x35.injective.oracle.v1beta1.QueryBandPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryBandPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/band_price_states\x12\xc2\x01\n\x12\x42\x61ndIBCPriceStates\x12\x38.injective.oracle.v1beta1.QueryBandIBCPriceStatesRequest\x1a\x39.injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/band_ibc_price_states\x12\xc9\x01\n\x14PriceFeedPriceStates\x12:.injective.oracle.v1beta1.QueryPriceFeedPriceStatesRequest\x1a;.injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/oracle/v1beta1/pricefeed_price_states\x12\xc5\x01\n\x13\x43oinbasePriceStates\x12\x39.injective.oracle.v1beta1.QueryCoinbasePriceStatesRequest\x1a:.injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/coinbase_price_states\x12\xd5\x01\n\x12ProviderPriceState\x12\x38.injective.oracle.v1beta1.QueryProviderPriceStateRequest\x1a\x39.injective.oracle.v1beta1.QueryProviderPriceStateResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}\x12\xaa\x01\n\x11OracleModuleState\x12\x31.injective.oracle.v1beta1.QueryModuleStateRequest\x1a\x32.injective.oracle.v1beta1.QueryModuleStateResponse\".\x82\xd3\xe4\x93\x02(\x12&/injective/oracle/v1beta1/module_state\x12\xd1\x01\n\x16HistoricalPriceRecords\x12<.injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest\x1a=.injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/oracle/v1beta1/historical_price_records\x12\xb1\x01\n\x10OracleVolatility\x12\x36.injective.oracle.v1beta1.QueryOracleVolatilityRequest\x1a\x37.injective.oracle.v1beta1.QueryOracleVolatilityResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/volatility\x12\xb9\x01\n\x13OracleProvidersInfo\x12\x39.injective.oracle.v1beta1.QueryOracleProvidersInfoRequest\x1a:.injective.oracle.v1beta1.QueryOracleProvidersInfoResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/oracle/v1beta1/providers\x12\xc2\x01\n\x14OracleProviderPrices\x12:.injective.oracle.v1beta1.QueryOracleProviderPricesRequest\x1a;.injective.oracle.v1beta1.QueryOracleProviderPricesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/oracle/v1beta1/provider_pricesBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_genesis__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='injective.oracle.v1beta1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=217,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='injective.oracle.v1beta1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.oracle.v1beta1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=296,
)


_QUERYBANDRELAYERSREQUEST = _descriptor.Descriptor(
  name='QueryBandRelayersRequest',
  full_name='injective.oracle.v1beta1.QueryBandRelayersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=324,
)


_QUERYBANDRELAYERSRESPONSE = _descriptor.Descriptor(
  name='QueryBandRelayersResponse',
  full_name='injective.oracle.v1beta1.QueryBandRelayersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayers', full_name='injective.oracle.v1beta1.QueryBandRelayersResponse.relayers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=371,
)


_QUERYBANDPRICESTATESREQUEST = _descriptor.Descriptor(
  name='QueryBandPriceStatesRequest',
  full_name='injective.oracle.v1beta1.QueryBandPriceStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=402,
)


_QUERYBANDPRICESTATESRESPONSE = _descriptor.Descriptor(
  name='QueryBandPriceStatesResponse',
  full_name='injective.oracle.v1beta1.QueryBandPriceStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_states', full_name='injective.oracle.v1beta1.QueryBandPriceStatesResponse.price_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=498,
)


_QUERYBANDIBCPRICESTATESREQUEST = _descriptor.Descriptor(
  name='QueryBandIBCPriceStatesRequest',
  full_name='injective.oracle.v1beta1.QueryBandIBCPriceStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=532,
)


_QUERYBANDIBCPRICESTATESRESPONSE = _descriptor.Descriptor(
  name='QueryBandIBCPriceStatesResponse',
  full_name='injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_states', full_name='injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse.price_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=631,
)


_QUERYPRICEFEEDPRICESTATESREQUEST = _descriptor.Descriptor(
  name='QueryPriceFeedPriceStatesRequest',
  full_name='injective.oracle.v1beta1.QueryPriceFeedPriceStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=667,
)


_QUERYPRICEFEEDPRICESTATESRESPONSE = _descriptor.Descriptor(
  name='QueryPriceFeedPriceStatesResponse',
  full_name='injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_states', full_name='injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse.price_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=768,
)


_QUERYCOINBASEPRICESTATESREQUEST = _descriptor.Descriptor(
  name='QueryCoinbasePriceStatesRequest',
  full_name='injective.oracle.v1beta1.QueryCoinbasePriceStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=803,
)


_QUERYCOINBASEPRICESTATESRESPONSE = _descriptor.Descriptor(
  name='QueryCoinbasePriceStatesResponse',
  full_name='injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_states', full_name='injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse.price_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=805,
  serialized_end=907,
)


_QUERYPROVIDERPRICESTATEREQUEST = _descriptor.Descriptor(
  name='QueryProviderPriceStateRequest',
  full_name='injective.oracle.v1beta1.QueryProviderPriceStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.oracle.v1beta1.QueryProviderPriceStateRequest.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.QueryProviderPriceStateRequest.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=975,
)


_QUERYPROVIDERPRICESTATERESPONSE = _descriptor.Descriptor(
  name='QueryProviderPriceStateResponse',
  full_name='injective.oracle.v1beta1.QueryProviderPriceStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_state', full_name='injective.oracle.v1beta1.QueryProviderPriceStateResponse.price_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=1069,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.oracle.v1beta1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1096,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.oracle.v1beta1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.oracle.v1beta1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1098,
  serialized_end=1179,
)


_QUERYHISTORICALPRICERECORDSREQUEST = _descriptor.Descriptor(
  name='QueryHistoricalPriceRecordsRequest',
  full_name='injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle', full_name='injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest.oracle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest.symbol_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1290,
)


_QUERYHISTORICALPRICERECORDSRESPONSE = _descriptor.Descriptor(
  name='QueryHistoricalPriceRecordsResponse',
  full_name='injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_records', full_name='injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse.price_records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1292,
  serialized_end=1392,
)


_ORACLEHISTORYOPTIONS = _descriptor.Descriptor(
  name='OracleHistoryOptions',
  full_name='injective.oracle.v1beta1.OracleHistoryOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_age', full_name='injective.oracle.v1beta1.OracleHistoryOptions.max_age', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_raw_history', full_name='injective.oracle.v1beta1.OracleHistoryOptions.include_raw_history', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_metadata', full_name='injective.oracle.v1beta1.OracleHistoryOptions.include_metadata', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1488,
)


_QUERYORACLEVOLATILITYREQUEST = _descriptor.Descriptor(
  name='QueryOracleVolatilityRequest',
  full_name='injective.oracle.v1beta1.QueryOracleVolatilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_info', full_name='injective.oracle.v1beta1.QueryOracleVolatilityRequest.base_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_info', full_name='injective.oracle.v1beta1.QueryOracleVolatilityRequest.quote_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_history_options', full_name='injective.oracle.v1beta1.QueryOracleVolatilityRequest.oracle_history_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1491,
  serialized_end=1716,
)


_QUERYORACLEVOLATILITYRESPONSE = _descriptor.Descriptor(
  name='QueryOracleVolatilityResponse',
  full_name='injective.oracle.v1beta1.QueryOracleVolatilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volatility', full_name='injective.oracle.v1beta1.QueryOracleVolatilityResponse.volatility', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history_metadata', full_name='injective.oracle.v1beta1.QueryOracleVolatilityResponse.history_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_history', full_name='injective.oracle.v1beta1.QueryOracleVolatilityResponse.raw_history', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1946,
)


_QUERYORACLEPROVIDERSINFOREQUEST = _descriptor.Descriptor(
  name='QueryOracleProvidersInfoRequest',
  full_name='injective.oracle.v1beta1.QueryOracleProvidersInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1948,
  serialized_end=1981,
)


_QUERYORACLEPROVIDERSINFORESPONSE = _descriptor.Descriptor(
  name='QueryOracleProvidersInfoResponse',
  full_name='injective.oracle.v1beta1.QueryOracleProvidersInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='injective.oracle.v1beta1.QueryOracleProvidersInfoResponse.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1983,
  serialized_end=2076,
)


_QUERYORACLEPROVIDERPRICESREQUEST = _descriptor.Descriptor(
  name='QueryOracleProviderPricesRequest',
  full_name='injective.oracle.v1beta1.QueryOracleProviderPricesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.oracle.v1beta1.QueryOracleProviderPricesRequest.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2130,
)


_QUERYORACLEPROVIDERPRICESRESPONSE = _descriptor.Descriptor(
  name='QueryOracleProviderPricesResponse',
  full_name='injective.oracle.v1beta1.QueryOracleProviderPricesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providerState', full_name='injective.oracle.v1beta1.QueryOracleProviderPricesResponse.providerState', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2231,
)

_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PARAMS
_QUERYBANDPRICESTATESRESPONSE.fields_by_name['price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._BANDPRICESTATE
_QUERYBANDIBCPRICESTATESRESPONSE.fields_by_name['price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._BANDPRICESTATE
_QUERYPRICEFEEDPRICESTATESRESPONSE.fields_by_name['price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PRICEFEEDSTATE
_QUERYCOINBASEPRICESTATESRESPONSE.fields_by_name['price_states'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._COINBASEPRICESTATE
_QUERYPROVIDERPRICESTATERESPONSE.fields_by_name['price_state'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PRICESTATE
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_oracle_dot_v1beta1_dot_genesis__pb2._GENESISSTATE
_QUERYHISTORICALPRICERECORDSREQUEST.fields_by_name['oracle'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_QUERYHISTORICALPRICERECORDSRESPONSE.fields_by_name['price_records'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PRICERECORDS
_QUERYORACLEVOLATILITYREQUEST.fields_by_name['base_info'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLEINFO
_QUERYORACLEVOLATILITYREQUEST.fields_by_name['quote_info'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLEINFO
_QUERYORACLEVOLATILITYREQUEST.fields_by_name['oracle_history_options'].message_type = _ORACLEHISTORYOPTIONS
_QUERYORACLEVOLATILITYRESPONSE.fields_by_name['history_metadata'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._METADATASTATISTICS
_QUERYORACLEVOLATILITYRESPONSE.fields_by_name['raw_history'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PRICERECORD
_QUERYORACLEPROVIDERSINFORESPONSE.fields_by_name['providers'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PROVIDERINFO
_QUERYORACLEPROVIDERPRICESRESPONSE.fields_by_name['providerState'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._PROVIDERSTATE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryBandRelayersRequest'] = _QUERYBANDRELAYERSREQUEST
DESCRIPTOR.message_types_by_name['QueryBandRelayersResponse'] = _QUERYBANDRELAYERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryBandPriceStatesRequest'] = _QUERYBANDPRICESTATESREQUEST
DESCRIPTOR.message_types_by_name['QueryBandPriceStatesResponse'] = _QUERYBANDPRICESTATESRESPONSE
DESCRIPTOR.message_types_by_name['QueryBandIBCPriceStatesRequest'] = _QUERYBANDIBCPRICESTATESREQUEST
DESCRIPTOR.message_types_by_name['QueryBandIBCPriceStatesResponse'] = _QUERYBANDIBCPRICESTATESRESPONSE
DESCRIPTOR.message_types_by_name['QueryPriceFeedPriceStatesRequest'] = _QUERYPRICEFEEDPRICESTATESREQUEST
DESCRIPTOR.message_types_by_name['QueryPriceFeedPriceStatesResponse'] = _QUERYPRICEFEEDPRICESTATESRESPONSE
DESCRIPTOR.message_types_by_name['QueryCoinbasePriceStatesRequest'] = _QUERYCOINBASEPRICESTATESREQUEST
DESCRIPTOR.message_types_by_name['QueryCoinbasePriceStatesResponse'] = _QUERYCOINBASEPRICESTATESRESPONSE
DESCRIPTOR.message_types_by_name['QueryProviderPriceStateRequest'] = _QUERYPROVIDERPRICESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryProviderPriceStateResponse'] = _QUERYPROVIDERPRICESTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryHistoricalPriceRecordsRequest'] = _QUERYHISTORICALPRICERECORDSREQUEST
DESCRIPTOR.message_types_by_name['QueryHistoricalPriceRecordsResponse'] = _QUERYHISTORICALPRICERECORDSRESPONSE
DESCRIPTOR.message_types_by_name['OracleHistoryOptions'] = _ORACLEHISTORYOPTIONS
DESCRIPTOR.message_types_by_name['QueryOracleVolatilityRequest'] = _QUERYORACLEVOLATILITYREQUEST
DESCRIPTOR.message_types_by_name['QueryOracleVolatilityResponse'] = _QUERYORACLEVOLATILITYRESPONSE
DESCRIPTOR.message_types_by_name['QueryOracleProvidersInfoRequest'] = _QUERYORACLEPROVIDERSINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryOracleProvidersInfoResponse'] = _QUERYORACLEPROVIDERSINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryOracleProviderPricesRequest'] = _QUERYORACLEPROVIDERPRICESREQUEST
DESCRIPTOR.message_types_by_name['QueryOracleProviderPricesResponse'] = _QUERYORACLEPROVIDERPRICESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryBandRelayersRequest = _reflection.GeneratedProtocolMessageType('QueryBandRelayersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANDRELAYERSREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryBandRelayersRequest)
  })
_sym_db.RegisterMessage(QueryBandRelayersRequest)

QueryBandRelayersResponse = _reflection.GeneratedProtocolMessageType('QueryBandRelayersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANDRELAYERSRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryBandRelayersResponse)
  })
_sym_db.RegisterMessage(QueryBandRelayersResponse)

QueryBandPriceStatesRequest = _reflection.GeneratedProtocolMessageType('QueryBandPriceStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANDPRICESTATESREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryBandPriceStatesRequest)
  })
_sym_db.RegisterMessage(QueryBandPriceStatesRequest)

QueryBandPriceStatesResponse = _reflection.GeneratedProtocolMessageType('QueryBandPriceStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANDPRICESTATESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryBandPriceStatesResponse)
  })
_sym_db.RegisterMessage(QueryBandPriceStatesResponse)

QueryBandIBCPriceStatesRequest = _reflection.GeneratedProtocolMessageType('QueryBandIBCPriceStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANDIBCPRICESTATESREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryBandIBCPriceStatesRequest)
  })
_sym_db.RegisterMessage(QueryBandIBCPriceStatesRequest)

QueryBandIBCPriceStatesResponse = _reflection.GeneratedProtocolMessageType('QueryBandIBCPriceStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBANDIBCPRICESTATESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse)
  })
_sym_db.RegisterMessage(QueryBandIBCPriceStatesResponse)

QueryPriceFeedPriceStatesRequest = _reflection.GeneratedProtocolMessageType('QueryPriceFeedPriceStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICEFEEDPRICESTATESREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryPriceFeedPriceStatesRequest)
  })
_sym_db.RegisterMessage(QueryPriceFeedPriceStatesRequest)

QueryPriceFeedPriceStatesResponse = _reflection.GeneratedProtocolMessageType('QueryPriceFeedPriceStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICEFEEDPRICESTATESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse)
  })
_sym_db.RegisterMessage(QueryPriceFeedPriceStatesResponse)

QueryCoinbasePriceStatesRequest = _reflection.GeneratedProtocolMessageType('QueryCoinbasePriceStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOINBASEPRICESTATESREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryCoinbasePriceStatesRequest)
  })
_sym_db.RegisterMessage(QueryCoinbasePriceStatesRequest)

QueryCoinbasePriceStatesResponse = _reflection.GeneratedProtocolMessageType('QueryCoinbasePriceStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOINBASEPRICESTATESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse)
  })
_sym_db.RegisterMessage(QueryCoinbasePriceStatesResponse)

QueryProviderPriceStateRequest = _reflection.GeneratedProtocolMessageType('QueryProviderPriceStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPROVIDERPRICESTATEREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryProviderPriceStateRequest)
  })
_sym_db.RegisterMessage(QueryProviderPriceStateRequest)

QueryProviderPriceStateResponse = _reflection.GeneratedProtocolMessageType('QueryProviderPriceStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPROVIDERPRICESTATERESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryProviderPriceStateResponse)
  })
_sym_db.RegisterMessage(QueryProviderPriceStateResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)

QueryHistoricalPriceRecordsRequest = _reflection.GeneratedProtocolMessageType('QueryHistoricalPriceRecordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALPRICERECORDSREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest)
  })
_sym_db.RegisterMessage(QueryHistoricalPriceRecordsRequest)

QueryHistoricalPriceRecordsResponse = _reflection.GeneratedProtocolMessageType('QueryHistoricalPriceRecordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALPRICERECORDSRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse)
  })
_sym_db.RegisterMessage(QueryHistoricalPriceRecordsResponse)

OracleHistoryOptions = _reflection.GeneratedProtocolMessageType('OracleHistoryOptions', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEHISTORYOPTIONS,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.OracleHistoryOptions)
  })
_sym_db.RegisterMessage(OracleHistoryOptions)

QueryOracleVolatilityRequest = _reflection.GeneratedProtocolMessageType('QueryOracleVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLEVOLATILITYREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryOracleVolatilityRequest)
  })
_sym_db.RegisterMessage(QueryOracleVolatilityRequest)

QueryOracleVolatilityResponse = _reflection.GeneratedProtocolMessageType('QueryOracleVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLEVOLATILITYRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryOracleVolatilityResponse)
  })
_sym_db.RegisterMessage(QueryOracleVolatilityResponse)

QueryOracleProvidersInfoRequest = _reflection.GeneratedProtocolMessageType('QueryOracleProvidersInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLEPROVIDERSINFOREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryOracleProvidersInfoRequest)
  })
_sym_db.RegisterMessage(QueryOracleProvidersInfoRequest)

QueryOracleProvidersInfoResponse = _reflection.GeneratedProtocolMessageType('QueryOracleProvidersInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLEPROVIDERSINFORESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryOracleProvidersInfoResponse)
  })
_sym_db.RegisterMessage(QueryOracleProvidersInfoResponse)

QueryOracleProviderPricesRequest = _reflection.GeneratedProtocolMessageType('QueryOracleProviderPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLEPROVIDERPRICESREQUEST,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryOracleProviderPricesRequest)
  })
_sym_db.RegisterMessage(QueryOracleProviderPricesRequest)

QueryOracleProviderPricesResponse = _reflection.GeneratedProtocolMessageType('QueryOracleProviderPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLEPROVIDERPRICESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.QueryOracleProviderPricesResponse)
  })
_sym_db.RegisterMessage(QueryOracleProviderPricesResponse)


DESCRIPTOR._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYORACLEVOLATILITYRESPONSE.fields_by_name['volatility']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.oracle.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2234,
  serialized_end=4509,
  methods=[
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='injective.oracle.v1beta1.Query.Params',
    index=0,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /injective/oracle/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BandRelayers',
    full_name='injective.oracle.v1beta1.Query.BandRelayers',
    index=1,
    containing_service=None,
    input_type=_QUERYBANDRELAYERSREQUEST,
    output_type=_QUERYBANDRELAYERSRESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/injective/oracle/v1beta1/band_relayers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BandPriceStates',
    full_name='injective.oracle.v1beta1.Query.BandPriceStates',
    index=2,
    containing_service=None,
    input_type=_QUERYBANDPRICESTATESREQUEST,
    output_type=_QUERYBANDPRICESTATESRESPONSE,
    serialized_options=b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/band_price_states',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BandIBCPriceStates',
    full_name='injective.oracle.v1beta1.Query.BandIBCPriceStates',
    index=3,
    containing_service=None,
    input_type=_QUERYBANDIBCPRICESTATESREQUEST,
    output_type=_QUERYBANDIBCPRICESTATESRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//injective/oracle/v1beta1/band_ibc_price_states',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PriceFeedPriceStates',
    full_name='injective.oracle.v1beta1.Query.PriceFeedPriceStates',
    index=4,
    containing_service=None,
    input_type=_QUERYPRICEFEEDPRICESTATESREQUEST,
    output_type=_QUERYPRICEFEEDPRICESTATESRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/injective/oracle/v1beta1/pricefeed_price_states',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CoinbasePriceStates',
    full_name='injective.oracle.v1beta1.Query.CoinbasePriceStates',
    index=5,
    containing_service=None,
    input_type=_QUERYCOINBASEPRICESTATESREQUEST,
    output_type=_QUERYCOINBASEPRICESTATESRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//injective/oracle/v1beta1/coinbase_price_states',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProviderPriceState',
    full_name='injective.oracle.v1beta1.Query.ProviderPriceState',
    index=6,
    containing_service=None,
    input_type=_QUERYPROVIDERPRICESTATEREQUEST,
    output_type=_QUERYPROVIDERPRICESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002D\022B/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OracleModuleState',
    full_name='injective.oracle.v1beta1.Query.OracleModuleState',
    index=7,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/injective/oracle/v1beta1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HistoricalPriceRecords',
    full_name='injective.oracle.v1beta1.Query.HistoricalPriceRecords',
    index=8,
    containing_service=None,
    input_type=_QUERYHISTORICALPRICERECORDSREQUEST,
    output_type=_QUERYHISTORICALPRICERECORDSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/injective/oracle/v1beta1/historical_price_records',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OracleVolatility',
    full_name='injective.oracle.v1beta1.Query.OracleVolatility',
    index=9,
    containing_service=None,
    input_type=_QUERYORACLEVOLATILITYREQUEST,
    output_type=_QUERYORACLEVOLATILITYRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/volatility',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OracleProvidersInfo',
    full_name='injective.oracle.v1beta1.Query.OracleProvidersInfo',
    index=10,
    containing_service=None,
    input_type=_QUERYORACLEPROVIDERSINFOREQUEST,
    output_type=_QUERYORACLEPROVIDERSINFORESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/injective/oracle/v1beta1/providers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OracleProviderPrices',
    full_name='injective.oracle.v1beta1.Query.OracleProviderPrices',
    index=11,
    containing_service=None,
    input_type=_QUERYORACLEPROVIDERPRICESREQUEST,
    output_type=_QUERYORACLEPROVIDERPRICESRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/injective/oracle/v1beta1/provider_prices',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_auction_rpc_pb2 as exchange_dot_injective__auction__rpc__pb2


class InjectiveAuctionRPCStub(object):
    """InjectiveAuctionRPC defines gRPC API of the Auction API.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AuctionEndpoint = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/AuctionEndpoint',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionResponse.FromString,
                )
        self.Auctions = channel.unary_unary(
                '/injective_auction_rpc.InjectiveAuctionRPC/Auctions',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsResponse.FromString,
                )
        self.StreamBids = channel.unary_stream(
                '/injective_auction_rpc.InjectiveAuctionRPC/StreamBids',
                request_serializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsResponse.FromString,
                )


class InjectiveAuctionRPCServicer(object):
    """InjectiveAuctionRPC defines gRPC API of the Auction API.
    """

    def AuctionEndpoint(self, request, context):
        """Provide historical auction info for a given auction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Auctions(self, request, context):
        """Provide the historical auctions info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamBids(self, request, context):
        """StreamBids streams new bids of an auction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveAuctionRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AuctionEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.AuctionEndpoint,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionResponse.SerializeToString,
            ),
            'Auctions': grpc.unary_unary_rpc_method_handler(
                    servicer.Auctions,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.AuctionsRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.AuctionsResponse.SerializeToString,
            ),
            'StreamBids': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamBids,
                    request_deserializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsRequest.FromString,
                    response_serializer=exchange_dot_injective__auction__rpc__pb2.StreamBidsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_auction_rpc.InjectiveAuctionRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveAuctionRPC(object):
    """InjectiveAuctionRPC defines gRPC API of the Auction API.
    """

    @staticmethod
    def AuctionEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_auction_rpc.InjectiveAuctionRPC/AuctionEndpoint',
            exchange_dot_injective__auction__rpc__pb2.AuctionRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Auctions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_auction_rpc.InjectiveAuctionRPC/Auctions',
            exchange_dot_injective__auction__rpc__pb2.AuctionsRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.AuctionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamBids(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_auction_rpc.InjectiveAuctionRPC/StreamBids',
            exchange_dot_injective__auction__rpc__pb2.StreamBidsRequest.SerializeToString,
            exchange_dot_injective__auction__rpc__pb2.StreamBidsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
